from setuptools import setup, find_packages
setup(
    name = 'tidal-gui',
    version = '2022.01.18.2',
    license = "Apache2",
    description = "Tidal Music Downloader-GUI.",

    author = 'YaronH',
    author_email = "yaronhuang@foxmail.com",

    packages = find_packages(),
    include_package_data = True,
    platforms = "any",
    install_requires=["tidal-dl", "PyQt5"],
    entry_points={'console_scripts': [ 'tidal-gui = tidal_gui:main', ]}
)
